//=====================================================================================================
// AHRS.h
// S.O.H. Madgwick
// 25th August 2010
//=====================================================================================================
//
// See AHRS.c file for description.
//
//=====================================================================================================
#ifndef AHRS_h
#define AHRS_h

#include "mbed.h"

#define PI 3.1415926536


//---------------------------------------------------------------------------------------------------
// Function declaration

class AHRS {

public:
    /**
        * Constructor.
        *
        * Initializes filter variables.
        *
        * @param rate The rate at which the filter should be updated.
        */

    //AHRS(float rate, float gyroMeasError);
    AHRS(float rate);
    /*
     * @param a_x X-axis accelerometer reading in m/s/s.
     * @param a_y Y-axis accelerometer reading in m/s/s.
     * @param a_z Z-axis accelerometer reading in m/s/s.
     * @param g_x X-axis gyroscope reading in rad/s.
     * @param g_y Y-axis gyroscope reading in rad/s.
     * @param g_z Z-axis gyroscope reading in rad/s.
     * @param mx X-axis magnetometer reading.
     * @param my Y-axis magnetometer reading.
     * @param mz Z-axis magnetometer reading.
     */

    void AHRSupdate(float g_x, float g_y, float g_z, float a_x, float a_y, float a_z, float mx, float my, float mz);

    /**
       * Compute the Euler angles based on the current filter data.
       */
    void getValues(float * values);   
   
    void getYawPitchRoll(float *ypr);
    
    void computeEuler(float *angles);
    //float angles[4];
    /*
     * Get the current roll.
     *
     * @return The current roll angle in radians.
     */

    float getRoll(void);

    /**
      * Get the current pitch.
      *
      * @return The current pitch angle in radians.
      */

    float getPitch(void);

    /**
     * Get the current yaw.
     *
     * @return The current yaw angle in radians.
     */

    float getYaw(void);
   
    float q0;
    float q1;
    float q2;
    float q3;
    //float q[4];
    
private:
    
    int firstUpdate;
    float norm;

    //scaled integral error
    float exInt;
    float eyInt;
    float ezInt;
    
    //Sampling period
    float deltat;

    //Euler angles
    float phi;
    float theta;
    float psi;
    float ypr[3];

};

    float invSqrt(float number);
    
#endif
//=====================================================================================================
// End of file
//=====================================================================================================